#' Internal Counterparts Data
#'
#' This dataset is accessible through \link{ids_list_counterparts}.
#'
#' @keywords internal
"counterparts"

#' Internal Entities Data
#'
#' This dataset is accessible through \link{ids_list_entities}.
#'
#' @keywords internal
"entities"

#' Internal Series Data
#'
#' This dataset is accessible through \link{ids_list_series}.
#'
#' @keywords internal
"series"

#' Internal Series-Topics Data
#'
#' This dataset is accessible through \link{ids_list_series_topics}.
#'
#' @keywords internal
"series_topics"
